@@ -1,3 +1,11 @@
+/*
+* Copyright (c) 2014,2015 Christian Surlykke, Paulo Lieuthier
+*
+* This file is part of the LXQt project. <http://lxqt.org>
+* It is distributed under the LGPL 2.1 or later license.
+* Please refer to the LICENSE file for a copy of the license.
+*/
+
 #ifndef WATCHER_H
 #define WATCHER_H
 
@@ -21,9 +29,8 @@ signals:
     void done();
 
 private:
-    LxQt::Power mPower;
-    LxQt::ScreenSaver mScreenSaver;
-    QEventLoop mLoop;
+    LXQt::Power mPower;
+    LXQt::ScreenSaver mScreenSaver;
 };
 
 #endif // WATCHER_H
